@@ -53,6 +53,11 @@ import requests_file
 import sqlite3
 import xdg.BaseDirectory as xdg_base_dirs
 
+try:
+    import dateparser
+except ImportError:
+    dateparser = False
+
 
 class FeedManager(object):
     """a feed manager fetches and stores feeds.
@@ -66,6 +71,10 @@ class FeedManager(object):
         self.conf_path = conf_path
         self.db_path = db_path
         self.conf_storage = FeedConfStorage(self.conf_path, pattern=pattern)
+        if dateparser:
+            def dateparser_tuple_parser(string):
+                return dateparser.parse(string).utctimetuple()
+            feedparser.registerDateHandler(dateparser_tuple_parser)
 
     def __repr__(self):
         return 'FeedManager(%s, %s, %s)' % (self.conf_path, self.db_path, self.pattern)
@@ -304,10 +313,7 @@ class Feed(feedparser.FeedParserDict):
         we do the following operation:
 
          1. add more defaults to item dates (`issue #113
-            <https://github.com/kurtmckee/feedparser/issues/113>`_):
-
-            * created_parsed of the item
-            * updated_parsed of the feed
+            <https://github.com/kurtmckee/feedparser/issues/113>`_)
 
          2. missing GUID in some feeds (`issue #112
             <https://github.com/kurtmckee/feedparser/issues/112>`_)
@@ -316,11 +322,30 @@ class Feed(feedparser.FeedParserDict):
             where feeds are /foo instead of https://github.com/foo.
             unreported for now.
         """
+
         # 1. add more defaults (issue #113)
+        def pick_first_date():
+            """find a valid date in item or feed"""
+            fields = ('updated_parsed', 'published_parsed', 'created_parsed')
+            # first check the item itself, then fallback on the field
+            for scope in (item, self):
+                # all the fields to inspect
+                for field in fields:
+                    if scope.get(field, False):
+                        logging.debug('picked field %s for item %s: %s',
+                                      field, item.get('id'), scope.get(field))
+                        return scope.get(field)
+
+        # ignore deprecation warnings from feedparser:
+        # https://github.com/kurtmckee/feedparser/issues/151
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
-            item['updated_parsed'] = item.get('updated_parsed', item.get('published_parsed', item.get('created_parsed', self.get('updated_parsed', self.get('published_parsed', False)))))  # noqa
-            assert item.get('updated_parsed') is not None
+            item['updated_parsed'] = pick_first_date()
+
+        if not item.get('updated_parsed'):
+            logging.warning('no parseable date found in feed item %s from feed %s, using current time instead',
+                            item.get('id'), self.get('url'))
+            item['updated_parsed'] = datetime.utcnow().timestamp()
 
         # 2. add UID if missing (issue #112)
         if not item.get('id'):
@@ -372,9 +397,10 @@ class Feed(feedparser.FeedParserDict):
         for (key, val) in data['feed'].items():
             if key not in self and key not in Feed.locked_keys:
                 self[key] = val
+        # import json
         # logging.debug('parsed structure %s',
         #               json.dumps(data, indent=2, sort_keys=True,
-        #                          default=safe_serial))
+        #                          default=str))
         # massage result for multiprocessing module
         if data['bozo']:
             data['bozo_exception'] = str(data['bozo_exception'])
